==> pyqryptonight-0.6.1.tar.gz: pyqryptonight-0.6.1/tests/python/test_powhelper.py <==
# Distributed under the MIT software license, see the accompanying
# file LICENSE or http://www.opensource.org/licenses/mit-license.php.
from unittest import TestCase
from pyqryptonight.pyqryptonight import StringToUInt256, UInt256ToString

from pyqryptonight.pyqryptonight import PoWHelper


class TestPowHelper(TestCase):
    def __init__(self, *args, **kwargs):
        super(TestPowHelper, self).__init__(*args, **kwargs)

    def test_boundary(self):
        ph = PoWHelper()

        difficulty = (
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
            0x00, 0x00, 0x00, 0x00, 0x00, 0x0F, 0x42, 0x40
        )

        boundary = ph.getBoundary(difficulty)

        expected_boundary = (
            0, 0, 16, 198, 247, 160, 181, 237,
            141, 54, 180, 199, 243, 73, 56, 88,
            54, 33, 250, 252, 139, 0, 121, 162,
            131, 77, 38, 250, 63, 204, 158, 169
        )

        self.assertEqual(expected_boundary, boundary)

    def test_adaptive_boundary(self):
        ph = PoWHelper()

        parent_difficulty = StringToUInt256("5000")

        current_difficulty = ph.getDifficulty(measurement=104,
                                              parent_difficulty=parent_difficulty)

        expected_difficulty = '4644'

        print(parent_difficulty)
        print(expected_difficulty)
        print(current_difficulty)

        self.assertEqual(expected_difficulty, UInt256ToString(current_difficulty))

        boundary = ph.getBoundary(current_difficulty)
        expected_boundary = "24933697079525451210932597977753640795277774475805461679469763998258641180"

        self.assertEqual(expected_boundary, UInt256ToString(boundary))

==> pyqryptonight-0.8.6.tar.gz: pyqryptonight-0.8.6/tests/python/test_powhelper.py <==
# Distributed under the MIT software license, see the accompanying
# file LICENSE or http://www.opensource.org/licenses/mit-license.php.
from unittest import TestCase
from pyqryptonight.pyqryptonight import StringToUInt256, UInt256ToString

from pyqryptonight.pyqryptonight import PoWHelper


class TestPowHelper(TestCase):
    def __init__(self, *args, **kwargs):
        super(TestPowHelper, self).__init__(*args, **kwargs)

    def test_boundary(self):
        ph = PoWHelper()

        difficulty = (
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
            0x00, 0x00, 0x00, 0x00, 0x00, 0x0F, 0x42, 0x40
        )

        target = ph.getTarget(difficulty)

        expected_target = (
            169, 158, 204, 63, 250, 38, 77, 131,
            162, 121, 0, 139, 252, 250, 33, 54,
            88, 56, 73, 243, 199, 180, 54, 141,
            237, 181, 160, 247, 198, 16, 0, 0
        )

        self.assertEqual(expected_target, target)

    def test_adaptive_target(self):
        ph = PoWHelper()

        parent_difficulty = StringToUInt256("5000")

        current_difficulty = ph.getDifficulty(measurement=104,
                                              parent_difficulty=parent_difficulty)

        expected_difficulty = '4644'

        print(parent_difficulty)
        print(expected_difficulty)
        print(current_difficulty)

        self.assertEqual(expected_difficulty, UInt256ToString(current_difficulty))

        target = ph.getTarget(current_difficulty)
        expected_target = "12766941454368345787240450318120704813017110301439674670851728194227068997120"

        self.assertEqual(expected_target, UInt256ToString(target))
